==> language-javascript-2.1.3-sources.jar: com/blacksquircle/ui/language/javascript/JavaScriptLanguage.kt <==
/*
 * Copyright 2022 Squircle IDE contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.blacksquircle.ui.language.javascript

import com.blacksquircle.ui.language.base.Language
import com.blacksquircle.ui.language.base.parser.LanguageParser
import com.blacksquircle.ui.language.base.provider.SuggestionProvider
import com.blacksquircle.ui.language.base.styler.LanguageStyler
import com.blacksquircle.ui.language.base.utils.endsWith
import com.blacksquircle.ui.language.javascript.parser.JavaScriptParser
import com.blacksquircle.ui.language.javascript.provider.JavaScriptProvider
import com.blacksquircle.ui.language.javascript.styler.JavaScriptStyler

class JavaScriptLanguage : Language {

    companion object {

        private val FILE_EXTENSIONS = arrayOf(".js", ".mjs", ".cjs")

        fun supportFormat(fileName: String): Boolean {
            return fileName.endsWith(FILE_EXTENSIONS)
        }
    }

    override val languageName = "javascript"

    override fun getParser(): LanguageParser {
        return JavaScriptParser.getInstance()
    }

    override fun getProvider(): SuggestionProvider {
        return JavaScriptProvider.getInstance()
    }

    override fun getStyler(): LanguageStyler {
        return JavaScriptStyler.getInstance()
    }
}

==> language-javascript-2.3.0-sources.jar: com/blacksquircle/ui/language/javascript/JavaScriptLanguage.kt <==
/*
 * Copyright 2023 Squircle CE contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.blacksquircle.ui.language.javascript

import com.blacksquircle.ui.language.base.Language
import com.blacksquircle.ui.language.base.parser.LanguageParser
import com.blacksquircle.ui.language.base.provider.SuggestionProvider
import com.blacksquircle.ui.language.base.styler.LanguageStyler
import com.blacksquircle.ui.language.base.utils.endsWith
import com.blacksquircle.ui.language.javascript.parser.JavaScriptParser
import com.blacksquircle.ui.language.javascript.provider.JavaScriptProvider
import com.blacksquircle.ui.language.javascript.styler.JavaScriptStyler

class JavaScriptLanguage : Language {

    companion object {

        const val LANGUAGE_NAME = "javascript"

        fun supportFormat(fileName: String): Boolean {
            return fileName.endsWith(".js", ".mjs", ".cjs")
        }
    }

    override val languageName = LANGUAGE_NAME

    override fun getParser(): LanguageParser {
        return JavaScriptParser.getInstance()
    }

    override fun getProvider(): SuggestionProvider {
        return JavaScriptProvider.getInstance()
    }

    override fun getStyler(): LanguageStyler {
        return JavaScriptStyler.getInstance()
    }
}
